﻿#===========================================================================
# 
# Script d'explication de traitement des fichiers XML
# 
# AC-Tech acsoyez.fr
#===========================================================================
[void][System.Reflection.Assembly]::LoadWithPartialName('presentationframework')
[xml]$xaml = @"
<Window
    xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
    x:Name="Window"
        Title="XML Register and Load" Height="198.585" Width="369.015" Foreground="{x:Null}" >
    <Grid Background="#FFE4E4E4">
        <Label Content="Item 1" HorizontalAlignment="Left" Margin="11,20,0,0" VerticalAlignment="Top"/>
        <TextBox Name="Txt_Item1" HorizontalAlignment="Left" Height="23" Margin="11,46,0,0" TextWrapping="Wrap" Text="Item 1" VerticalAlignment="Top" Width="156"/>
        <Label Content="Item 2" HorizontalAlignment="Left" Margin="172,20,0,0" VerticalAlignment="Top" RenderTransformOrigin="0.523,2.115"/>
        <TextBox Name="Txt_Item2" HorizontalAlignment="Left" Height="23" Margin="172,46,0,0" TextWrapping="Wrap" Text="Item 2" VerticalAlignment="Top" Width="154"/>
        <Button Name="Bt_SaveXML" Content="Save XML" HorizontalAlignment="Left" Margin="10,74,0,0" VerticalAlignment="Top" Width="75" BorderBrush="#FF00A29B" Background="#FF00A29B" Height="35"/>
        <Button Name="Bt_DeleteXML" Content="Delete XML" HorizontalAlignment="Left" Margin="92,74,0,0" VerticalAlignment="Top" Width="75" BorderBrush="#FFF79406" Background="#FFF79406" Height="35"/>
        <Button Name="Bt_Clean" Content="Clean Values" HorizontalAlignment="Left" Margin="172,74,0,0" VerticalAlignment="Top" Width="75" Background="#FF0097FF" BorderBrush="#FF0097FF" Height="35"/>
        <Button Name="Bt_Read" Content="Read XML" HorizontalAlignment="Left" Margin="251,74,0,0" VerticalAlignment="Top" Width="75" BorderBrush="#FFFF00AE" Background="#FFFF00AE" Height="35"/>
        <Label Content="AC-Tech" HorizontalAlignment="Left" Margin="0,133,0,0" VerticalAlignment="Top" FontWeight="Bold" Height="27" Width="64"/>
        <Label Name="Link" Content="https://acsoyez.fr" HorizontalAlignment="Left" Height="28" Margin="64,133,0,0" VerticalAlignment="Top" Width="106" Cursor="Hand"/>
        
    </Grid>
</Window>
"@
#Read XAML
$reader=(New-Object System.Xml.XmlNodeReader $xaml) 
try{$Form=[Windows.Markup.XamlReader]::Load( $reader )}
catch{Write-Host "Unable to load Windows.Markup.XamlReader. Some possible causes for this problem include: .NET Framework is missing PowerShell must be launched with PowerShell -sta, invalid XAML code was encountered."; exit}

#===========================================================================
# Store Form Objects In PowerShell
#===========================================================================
$xaml.SelectNodes("//*[@Name]") | %{Set-Variable -Name ($_.Name) -Value $Form.FindName($_.Name)}

$script = $MyInvocation.MyCommand.Name
$xmlpath = $PSScriptRoot + "\" +$script.Substring(0,$script.Length-4)+ ".xml"

$Link.Add_MouseLeftButtonUp({[system.Diagnostics.Process]::start('https://acsoyez.fr')})
$Link.Add_MouseEnter({$Link.Foreground = 'LightBlue'})
$Link.Add_MouseLeave({$Link.Foreground = 'Blue'})


#===========================================================================
# Functions
#===========================================================================
function CreateXMLGUI {
    
    if (test-path $xmlpath) { Remove-item $xmlpath -Force -Recurse }
    # Set The Formatting
    $xmlsettings = New-Object System.Xml.XmlWriterSettings
    $xmlsettings.Indent = $true
    $xmlsettings.IndentChars = "    "

    # Set the File Name Create The Document
    $XmlWriter = [System.XML.XmlWriter]::Create($xmlpath, $xmlsettings)

    # Write the XML Decleration and set the XSL
    $xmlWriter.WriteStartDocument()
    $xmlWriter.WriteProcessingInstruction("xml-stylesheet", "type='text/xsl' href='style.xsl'")

    $ValueItem1  = $Txt_Item1.Text
    $ValueItem2  = $Txt_Item2.Text

    # Start the Root Element
    $xmlWriter.WriteStartElement("XML-Work") # <-- Start <Root>
        $xmlWriter.WriteStartElement("Text") # <-- Start <Object>
            $xmlWriter.WriteElementString("ValueItem1","$ValueItem1")
            $xmlWriter.WriteElementString("ValueItem2","$ValueItem2")
        $xmlWriter.WriteEndElement() # <-- End <Object>
    $xmlWriter.WriteEndElement() # <-- End <Root> 

    # End, Finalize and close the XML Document
    $xmlWriter.WriteEndDocument()
    $xmlWriter.Flush()
    $xmlWriter.Close()
}

function Read-XML
{
    if (test-path $xmlpath)
    {
        Write-Host "Read XML: $xmlpath"
        [xml]$xml = get-content ("$xmlpath")
        foreach ($valeurxml in $xml.'XML-Work')
        { 
            $Txt_Item1.Text = $valeurxml.Text.ValueItem1
            $Txt_Item2.Text = $valeurxml.Text.ValueItem2
        }
    }
    else { Write-Host "no xml found" }
}

#===========================================================================
# Read XML at start
#===========================================================================
Read-XML
#===========================================================================
# Buttons Clicks
#===========================================================================
$Bt_SaveXML.add_Click({
    CreateXMLGUI
    Write-Host "$xmlpath created"
})

$Bt_DeleteXML.add_Click({
    if( test-path $xmlpath )
    {
        Remove-Item $xmlpath -Verbose -Force -Recurse
        Write-Host "$xmlpath deleted"
    }
    else { Write-Host "no xml found" }

})

$Bt_Clean.add_Click({
    $Txt_Item1.Text = ""
    $Txt_Item2.Text = ""
})

$Bt_Read.add_Click({
    Read-XML
})


#===========================================================================
# Show Window
#===========================================================================
$Form.ShowDialog() | out-null
